@@ -251,7 +251,7 @@ class MatchMaker:
             import alfred3 as al
             import alfred3_interact as ali
 
-            exp = Experiment()
+            exp = al.Experiment()
 
             @exp.setup
             def setup(exp):
@@ -371,7 +371,7 @@ class MatchMaker:
                 import alfred3 as al
                 import alfred3_interact as ali
 
-                exp = Experiment()
+                exp = al.Experiment()
 
                 @exp.setup
                 def setup(exp):
@@ -422,6 +422,8 @@ class MatchMaker:
                 not over yet. Thus, *nmin* can be used to cut the waiting
                 time short. Defaults to None, which means that waiting
                 time alone determines when matching will start.
+                **Note**: The parameter *nmin* will only take effect, if
+                *wait* is not *None*.
         
         This is the right method, if you wish to randomize participants
         into groups of different sizes. 
@@ -484,7 +486,7 @@ class MatchMaker:
                 import alfred3 as al
                 import alfred3_interact as ali
 
-                exp = Experiment()
+                exp = al.Experiment()
 
                 @exp.setup
                 def setup(exp):
@@ -585,7 +587,7 @@ class MatchMaker:
                 import alfred3 as al
                 import alfred3_interact as ali
 
-                exp = Experiment()
+                exp = al.Experiment()
 
                 @exp.setup
                 def setup(exp):
